<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0">
<context>
    <name>AdvancedConfigDialog</name>
    <message>
        <source>Advanced Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Crop Image When Loaded</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ConfigDialog</name>
    <message>
        <source>OCR Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>OCR Engine</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>cuneiform</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>tesseract</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Tesseract Setup</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Location of the  tessdata directory:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MainForm</name>
    <message>
        <source>Recognition language</source>
        <translation>Język rozpoznawania</translation>
    </message>
    <message>
        <source>Open Image</source>
        <translation>Otwórz plik graficzny</translation>
    </message>
    <message>
        <source>Image Files (*.png *.jpg *.jpeg *.bmp *.tiff *.tif *.gif *.pnm *.pgm *.pbm *.ppm)</source>
        <translation>Pliki graficzne  (*.png *.jpg *.jpeg *.bmp *.tiff *.tif *.gif *.pnm *.pgm *.pbm *.ppm)</translation>
    </message>
    <message>
        <source>There is an unsaved text in the editor window. Do you want to save it?</source>
        <translation>W oknie edytora jest niezapisany tekst. Zapisać?</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>Ostrzeżenie</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Błąd</translation>
    </message>
    <message>
        <source>No image loaded</source>
        <translation>Brak załadowanego obrazka</translation>
    </message>
    <message>
        <source>Starting cuneiform failed</source>
        <translation>Nie udało się uruchomić cuneiform</translation>
    </message>
    <message>
        <source>The system said: </source>
        <translation>Odpowiedź systemu:</translation>
    </message>
    <message>
        <source>program not found</source>
        <translation>nie znaleziono programu</translation>
    </message>
    <message>
        <source>About YAGF</source>
        <translation>О programie</translation>
    </message>
    <message>
        <source>http://symmetrica.net/cuneiform-linux/yagf-en.html</source>
        <translation>http://symmetrica.net/cuneiform-linux/yagf-pl.html</translation>
    </message>
    <message>
        <source>Save Image</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Recognizing pages...</source>
        <translation>Rozpoznaję strony...</translation>
    </message>
    <message>
        <source>Abort</source>
        <translation>Przerwij</translation>
    </message>
    <message>
        <source>Importing pages from the PDF document...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No compatible PDF converter software could be found. Please install either the pdftoppm utility or the GhostScript package (from this the gs command will be required).</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>PDF file name may not be empty</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select an existing directory for output or create some new one</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Selecting Directory</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The selected directory is not empty</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Starting tesseract failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>cuneiform not found, switching to tesseract</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No recognition engine found.
Please install either cuneiform or tesseract</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>tesseract not found, switching to cuneiform</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No PDF converter installed</source>
        <translation type="unfinished"></translation>
    </message>
    <message utf8="true">
        <source>&lt;p align=&quot;center&quot;&gt;&lt;b&gt;YAGF - Yet Another Graphical Front-end for cuneiform and tesseract OCR engines&lt;/b&gt;&lt;/p&gt;&lt;p align=&quot;center&quot;&gt;Version %1&lt;/p&gt; &lt;p align=&quot;center&quot;&gt;Ⓒ 2009-2012 Andrei Borovsky&lt;/p&gt; This is a free software distributed under GPL v3. Visit &lt;a href=&quot;http://symmetrica.net/cuneiform-linux/yagf-en.html&quot;&gt;http://symmetrica.net/cuneiform-linux/yagf-en.html&lt;/a&gt; for more details.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Using Cuneiform</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Using Tesseract</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Scanning is impossible</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No scanning front-end is found. Please install XSane in order to perform scanning.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed to Load Image</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed to detect text areas on this page.
The page possibly lacks contrast. Try to select blocks manually.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The selected directoy is not empty. Please select or create another one.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed to save the project.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed to load project.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>S&amp;can...</source>
        <translation>S&amp;kanuj...</translation>
    </message>
    <message>
        <source>Scanning images using XSane...</source>
        <translation>Skanuję strony używając XSane...</translation>
    </message>
    <message>
        <source>&amp;Save text...</source>
        <translation>&amp;Zapisz tekst...</translation>
    </message>
    <message>
        <source>&amp;Open Image...</source>
        <translation>&amp;Otwórz plik graficzny...</translation>
    </message>
    <message>
        <source>Open Image</source>
        <translation>Otwórz plik graficzny</translation>
    </message>
    <message>
        <source>&amp;Recognize</source>
        <translation>&amp;Распознать</translation>
    </message>
    <message>
        <source>Recognizing text...</source>
        <translation>Rozpoznaj tekst...</translation>
    </message>
    <message>
        <source>Choose &amp;Language</source>
        <translation>&amp;Wybierz język</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation>Zakończ</translation>
    </message>
    <message>
        <source>Previous page</source>
        <translation>Poprzednia strona</translation>
    </message>
    <message>
        <source>Move to previous image</source>
        <translation>Przejdź do poprzedniej grafiki</translation>
    </message>
    <message>
        <source>Next page</source>
        <translation>Następna strona</translation>
    </message>
    <message>
        <source>Move to next image</source>
        <translation>Przejdź do następnej grafiki</translation>
    </message>
    <message>
        <source>Online Help</source>
        <translation>Pomoc online</translation>
    </message>
    <message>
        <source>About...</source>
        <translation>O programie...</translation>
    </message>
    <message>
        <source>Clear all blocks</source>
        <translation>Oczyść wszystkie bloki</translation>
    </message>
    <message>
        <source>Delete the current block</source>
        <translation>Usuń bieżący blok</translation>
    </message>
    <message>
        <source>Recognize block</source>
        <translation>Rozpoznaj blok</translation>
    </message>
    <message>
        <source>Recognize this block</source>
        <translation>Rozpoznaj ten blok</translation>
    </message>
    <message>
        <source>Clear numbers</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Crear block numbering</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Check spelling</source>
        <translation type="unfinished">Sprawdzanie pisowni</translation>
    </message>
    <message>
        <source>Save current image...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save currently opened image in its real size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save block</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save the current block to the image file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select HTML format</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select HTML format as recognition output</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Larger view</source>
        <translation>Powiększ widok</translation>
    </message>
    <message>
        <source>Smaller view</source>
        <translation>Zmniejsz widok</translation>
    </message>
    <message>
        <source>Rotate 90 CCW</source>
        <translation>Obróć o 90 stopni w lewo</translation>
    </message>
    <message>
        <source>Rotate 180</source>
        <translation>Obróć o 180 stopni</translation>
    </message>
    <message>
        <source>Rotate 90 CW</source>
        <translation>Obróć o 90 stopni w lewo</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Plik</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Pomoc</translation>
    </message>
    <message>
        <source>Copy To Clipboard</source>
        <translation>Kopiuj do schowka</translation>
    </message>
    <message>
        <source>Copy recognized text to clipboard</source>
        <translation>Skopiuj rozpoznany tekst do schowka</translation>
    </message>
    <message>
        <source>MainWindow</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>toolBar</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+N</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+S</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+O</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+R</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+Q</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Recognize &amp;All Pages</source>
        <translation>Rozpoznaj &amp;wszystkie strony </translation>
    </message>
    <message>
        <source>Recognize All Pages</source>
        <translation>Rozpoznaj wszystkie strony</translation>
    </message>
    <message>
        <source>Ctrl+A</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&lt;&lt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hide/Show Toolbar</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Import from PDF...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Import pages from PDF documents</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>OCR Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Set up the OCR parameters</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Paste Image</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Paste image from clipboard</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select Text Area</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Deskew  Block</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Deskew the current block</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Deskew</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Correct the page skew </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Advanced Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The settings you should probably never change</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>select multiple blocks</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Splits text into several blocks</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Toggle Large/Small Icons</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>toolBar_2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select Recognition Language</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Prepare Page</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save Project...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Load Project...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Prepare the page for recognition</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PopplerDialog</name>
    <message>
        <source>Import from PDF</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>File Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Pages</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>From</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>To</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Entire Document</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>JPEG Files (*.jpg)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>PNG Files (*.png)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed to save the image</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Required spelling dictionary (%1) is not found.
Spell-checking is disabled.
Try to install an appropriate aspell dictionary.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Warning</source>
        <translation type="unfinished">Ostrzeżenie</translation>
    </message>
    <message>
        <source>Select Project Directory</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Bulgarian</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Czech</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Danish</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Dutch</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>English</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>French</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>German</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hungarian</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Italian</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Latvian</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Lithuanian</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Polish</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Portuguese</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Romanian</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Russian</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Russian-English</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Spanish</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Serbian</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Slovenian</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Swedish</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ukrainian</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Finnish</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>German Gothic</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Greek</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hebrew</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Norwegian</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Slovak</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Swedish Gothic</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Turkish</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SideBar</name>
    <message>
        <source>Drop files here</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
